#
# spec file for package eet
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           eet
Version:        1.7.4
Release:        18.1
Summary:        Data encode/decode and storage library
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Url:            http://enlightenment.org/
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  doxygen
BuildRequires:  eina-devel >= %version
BuildRequires:  libjpeg-devel
BuildRequires:  openssl-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Eet is a tiny library designed to write an arbitrary set of chunks of
data to a file and optionally compress each chunk (very much like a
zip file) and allow fast random-access reading of the file later
on. It does not do zip as a zip itself has more complexity than is
needed, and it was much simpler to implement this once here.

It also can encode and decode data structures in memory, as well as
image data for saving to eet files or sending across the network to
other machines, or just writing to arbitrary files on the system. All
data is encoded in a platform independent way and can be written and
read by any architecture.


%package -n libeet1
Summary:        Eet Dynamic Libraries
Group:          System/Libraries

%description -n libeet1
Headers, static libraries, test programs and documentation for eet

%package devel
Summary:        Eet headers, static libraries, documentation and test programs
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       eina-devel >= %version
Requires:       libeet1 = %{version}
Requires:       libjpeg-devel
Requires:       openssl-devel
Requires:       pkgconfig
Requires:       zlib-devel

%description devel
Headers, static libraries, test programs and documentation for eina

%package doc-html
Summary:        HTML documentation of Eet
Group:          Documentation/HTML

%description doc-html
Documentation of Eet library in form of HTML pages.

%package doc-examples
Summary:        Example usage of Eet
Group:          Documentation/Other

%description doc-examples
Example usage of Eet library.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
# fix permissions
find %{buildroot}%{_docdir} -type f | xargs chmod 0644
find %{buildroot}%{_docdir} -type d | xargs chmod 0755
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm {} \;

%post -n libeet1 -p /sbin/ldconfig

%postun -n libeet1 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%dir %{_datadir}/eet/
%{_bindir}/eet

%files -n libeet1
%defattr(-,root,root)
%{_libdir}/libeet.so.1*

%files devel
%defattr(-, root, root)
%{_includedir}/eet-1/
%{_libdir}/pkgconfig/eet.pc
%{_libdir}/libeet.so

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-examples
%defattr(-, root, root)
%{_datadir}/eet/examples

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-18.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Eet 1.7.3:
  * Fix memory leak when using OpenSSL for ciphering long data.
  * Fix possible buffer overflow in functions relying on
    EET_T_LAST
* Wed Dec 19 2012 sleep_walker@suse.cz
- fix directory for HTML
* Wed Dec 19 2012 sleep_walker@suse.cz
- build and package documentation, separate examples
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
- 1.7.2 is required to build and use the latest e17 alpha's
* Thu Nov 22 2012 sleep_walker@suse.cz
- improve description (from eet.spec.in)
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Tue Nov 13 2012 cfarrell@suse.com
- license update: BSD-2-Clause
  SPDX format
* Tue Nov 13 2012 sleep_walker@suse.cz
- get rid of autoupdate entries in changes files
- correct license
* Sat Oct 20 2012 simon@simotek.net
- bump to 1.7.1
* Sun Sep  9 2012 sleep_walker@suse.cz
- remove forgoten directory in setup macro
* Fri Sep  7 2012 sleep_walker@suse.cz
- revert spec file change makeinstall --> make_install
* Sat Aug 11 2012 sleep_walker@suse.cz
- alter to 1.7.0-alpha
* Fri Dec 16 2011 sleep_walker@suse.cz
- pre_configure --> pre_configure_hook
* Mon Dec 12 2011 sleep_walker@suse.cz
- fix build after update - added example code - for now as part of eet package
* Sat Oct 22 2011 tcech@suse.com
- add autoreconf for Mandriva builds
* Sat Oct 15 2011 tcech@suse.com
- add devel packages required to build as required for devel package
* Thu Oct  6 2011 tcech@suse.com
- Add libopenssl-devel as requirement for devel package
* Wed Oct  5 2011 tcech@suse.com
- add support for openssl
* Mon Oct  3 2011 jreidinger@suse.com
- tweak a spec file
* Tue Aug 23 2011 sleep_walker@suse.cz
- attempt to make eet buildable on all supported RPM distributions
  %%make_install --> %%makeinstall
  find -delete --> find -exec rm {} \;
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package of eet, version 1.4.0
